@@ -1,5 +1,3 @@
-from typing import List, Optional, Tuple
-
 from fastapi import Depends, HTTPException, Query, status
 from pydantic import UUID4
 from sqlalchemy import select
@@ -17,11 +15,11 @@ from fief.repositories import ClientRepository
 
 
 async def get_paginated_clients(
-    query: Optional[str] = Query(None),
+    query: str | None = Query(None),
     pagination: Pagination = Depends(get_pagination),
     ordering: Ordering = Depends(get_ordering),
     repository: ClientRepository = Depends(get_workspace_repository(ClientRepository)),
-) -> Tuple[List[Client], int]:
+) -> tuple[list[Client], int]:
     statement = select(Client)
 
     if query is not None:
