@@ -1,5 +1,3 @@
-from typing import List, Tuple
-
 from fastapi import Depends, HTTPException, status
 from pydantic import UUID4
 from sqlalchemy import select
@@ -22,7 +20,7 @@ async def get_paginated_oauth_providers(
     repository: OAuthProviderRepository = Depends(
         get_workspace_repository(OAuthProviderRepository)
     ),
-) -> Tuple[List[OAuthProvider], int]:
+) -> tuple[list[OAuthProvider], int]:
     statement = select(OAuthProvider)
     return await get_paginated_objects(statement, pagination, ordering, repository)
 
@@ -45,5 +43,5 @@ async def get_oauth_providers(
     repository: OAuthProviderRepository = Depends(
         get_workspace_repository(OAuthProviderRepository)
     ),
-) -> List[OAuthProvider]:
+) -> list[OAuthProvider]:
     return await repository.all_by_name_and_provider()
