@@ -1,5 +1,3 @@
-from typing import List, Optional, Tuple
-
 from fastapi import Depends, HTTPException, Query, status
 from pydantic import UUID4
 from sqlalchemy import select
@@ -17,11 +15,11 @@ from fief.repositories import RoleRepository
 
 
 async def get_paginated_roles(
-    query: Optional[str] = Query(None),
+    query: str | None = Query(None),
     pagination: Pagination = Depends(get_pagination),
     ordering: Ordering = Depends(get_ordering),
     repository: RoleRepository = Depends(get_workspace_repository(RoleRepository)),
-) -> Tuple[List[Role], int]:
+) -> tuple[list[Role], int]:
     statement = select(Role)
 
     if query is not None:
