@@ -2,6 +2,7 @@ from fief.schemas import (
     admin_api_key,
     auth,
     client,
+    email_template,
     generics,
     oauth_account,
     oauth_provider,
@@ -21,6 +22,7 @@ __all__ = [
     "admin_api_key",
     "auth",
     "client",
+    "email_template",
     "generics",
     "oauth_account",
     "oauth_provider",
