@@ -1,6 +1,6 @@
 import base64
 from enum import Enum
-from typing import TYPE_CHECKING, Any, Dict, Optional, Tuple, Type
+from typing import TYPE_CHECKING, Any
 
 from httpx_oauth.clients.discord import DiscordOAuth2
 from httpx_oauth.clients.facebook import FacebookOAuth2
@@ -28,7 +28,7 @@ class AvailableOAuthProvider(str, Enum):
     OPENID = "OPENID"
 
 
-OAUTH_PROVIDERS: Dict[AvailableOAuthProvider, Type[BaseOAuth2]] = {
+OAUTH_PROVIDERS: dict[AvailableOAuthProvider, type[BaseOAuth2]] = {
     AvailableOAuthProvider.DISCORD: DiscordOAuth2,
     AvailableOAuthProvider.FACEBOOK: FacebookOAuth2,
     AvailableOAuthProvider.GITHUB: GitHubOAuth2,
@@ -42,12 +42,12 @@ OAUTH_PROVIDERS: Dict[AvailableOAuthProvider, Type[BaseOAuth2]] = {
 
 def get_oauth_provider_branding(
     oauth_provider: "OAuthProvider",
-) -> Tuple[str, Optional[str]]:
+) -> tuple[str, str | None]:
     provider_class = OAUTH_PROVIDERS[oauth_provider.provider]
     display_name: str = getattr(
         provider_class, "display_name", oauth_provider.name or ""
     )
-    logo_svg: Optional[str] = getattr(provider_class, "logo_svg", None)
+    logo_svg: str | None = getattr(provider_class, "logo_svg", None)
     if logo_svg:
         logo_svg = base64.b64encode(logo_svg.encode("utf-8")).decode("utf-8")
     return display_name, logo_svg
@@ -56,7 +56,7 @@ def get_oauth_provider_branding(
 def get_oauth_provider_service(oauth_provider: "OAuthProvider") -> BaseOAuth2:
     provider = oauth_provider.provider
     oauth_provider_class = OAUTH_PROVIDERS[provider]
-    oauth_provider_class_kwargs: Dict[str, Any] = {
+    oauth_provider_class_kwargs: dict[str, Any] = {
         "client_id": oauth_provider.client_id,
         "client_secret": oauth_provider.client_secret,
     }
@@ -69,7 +69,7 @@ def get_oauth_provider_service(oauth_provider: "OAuthProvider") -> BaseOAuth2:
 
 async def get_oauth_id_email(
     oauth_provider: "OAuthProvider", access_token: str
-) -> Tuple[str, Optional[str]]:
+) -> tuple[str, str | None]:
     oauth_provider_service = get_oauth_provider_service(oauth_provider)
 
     try:
